// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module requires `dataset-sioc` feature to be enabled.

use crate::dataset_from_path;

dataset_from_path!("../../ontologies/sioc.nq");
